@@ -96,49 +96,37 @@ static gboolean do_search(const char *url, const char *keyword)
 }
 
 
-/* redraw the plugin */
-static void update_search(t_search *search) {
-    DBG ("Update search");
-    gtk_widget_hide(GTK_WIDGET(search->box));
-    gtk_widget_hide(search->label);
-    gtk_label_set_text(GTK_LABEL(search->label), search->label_text);
-    gtk_widget_show(GTK_WIDGET(search->box));
-    if (search->hide_label) {
-        gtk_widget_show(search->label);
-    }
-}
-
-/* apply the new values to: url, label_text, size */
-static void search_apply_options_cb(t_search *search)
-{
-    DBG ("Apply options");
-    search->url = g_strdup(gtk_entry_get_text(GTK_ENTRY(search->url_entry)));
-    search->label_text = g_strdup(gtk_entry_get_text(GTK_ENTRY(search->label_entry)));
-    search->size = (gint)(gtk_spin_button_get_value(GTK_SPIN_BUTTON(search->size_spinner)));
-    search->hide_label = gtk_switch_get_active(GTK_SWITCH(search->hide_check));
-    gtk_entry_set_width_chars(GTK_ENTRY(search->entry), search->size);
-    update_search(search);
-}
-
 /* callback: apply the new value to the url string */
-static void url_entry_activate_cb(GtkWidget *widget, t_search *search)
+static void url_entry_changed_cb(GtkWidget *widget, t_search *search)
 {
-    DBG ("Activate url_entry");
+    DBG ("url_entry_changed_cb");
     search->url = g_strdup(gtk_entry_get_text(GTK_ENTRY(search->url_entry)));
-    update_search(search);
 }
 
 /* callback: apply the new value to the label_text string */
-static void text_entry_activate_cb(GtkWidget *widget, t_search *search)
+static void text_entry_changed_cb(GtkWidget *widget, t_search *search)
 {
-    DBG ("text_entry_activate_cb");
+    DBG ("text_entry_changed_cb");
     search->label_text = g_strdup(gtk_entry_get_text(GTK_ENTRY(search->label_entry)));
-    update_search(search);
+    gtk_label_set_text(GTK_LABEL(search->label), search->label_text);
 }
 
-void hide_check_toggled_cb(GtkWidget *widget, gboolean is_active, t_search *search)
+/* callback: apply the new size to the entry widget */
+static void entry_size_changed_cb(GtkWidget *widget, t_search *search)
 {
-    gtk_widget_set_sensitive (GTK_WIDGET(search->label_entry), is_active);
+    DBG ("entry_size_changed_cb");
+    search->size = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(search->size_spinner));
+    gtk_entry_set_width_chars(GTK_ENTRY(search->entry), search->size);
+}
+
+static gboolean hide_check_toggled_cb(GtkWidget *widget, gboolean is_active, t_search *search)
+{
+    DBG ("hide_check_toggled_cb");
+    search->hide_label = is_active;
+    gtk_widget_set_sensitive (GTK_WIDGET(search->label_entry), !is_active);
+    gtk_widget_set_visible (search->label, !is_active);
+    gtk_switch_set_state(GTK_SWITCH(search->hide_check), is_active);
+    return TRUE;
 }
 
 static gboolean entry_buttonpress_cb(GtkWidget *entry, GdkEventButton *event, XfcePanelPlugin *plugin)
@@ -285,12 +273,12 @@ static void search_create_options(XfcePanelPlugin *plugin, t_search *search)
     search->label_entry = gtk_entry_new();
     gtk_widget_show(search->label_entry);
     gtk_grid_attach(GTK_GRID(grid), GTK_WIDGET(search->label_entry), 1, 0, 1, 1);
-    gtk_widget_set_sensitive (GTK_WIDGET(search->label_entry), search->hide_label);
+    gtk_widget_set_sensitive (GTK_WIDGET(search->label_entry), !search->hide_label);
     /* text field */
     if(search->label_text)
         gtk_entry_set_text(GTK_ENTRY(search->label_entry), search->label_text);
     //DBG("connect signal");
-    g_signal_connect (GTK_WIDGET(search->label_entry), "activate", G_CALLBACK (text_entry_activate_cb), search);
+    g_signal_connect (GTK_WIDGET(search->label_entry), "changed", G_CALLBACK (text_entry_changed_cb), search);
 
     /* Hide label option */
     search->hide_check = gtk_switch_new();
@@ -304,9 +292,10 @@ static void search_create_options(XfcePanelPlugin *plugin, t_search *search)
     sizelabel = gtk_label_new(_("Size:"));
     gtk_grid_attach(GTK_GRID(grid), sizelabel, 0, 1, 1, 1);
     /* size spinner */
-    GtkAdjustment* spinner_adj = gtk_adjustment_new (search->size, 2.0, 10.0, 1.0, 5.0, 0);
+    GtkAdjustment* spinner_adj = gtk_adjustment_new (search->size, 2.0, 30.0, 1.0, 5.0, 0);
     search->size_spinner = gtk_spin_button_new(GTK_ADJUSTMENT(spinner_adj), 1.0, 0);
     gtk_grid_attach(GTK_GRID(grid), GTK_WIDGET(search->size_spinner), 1, 1, 1, 1);
+    g_signal_connect (GTK_WIDGET(search->size_spinner), "value-changed", G_CALLBACK (entry_size_changed_cb), search);
 
     /* url label */
     urllabel = gtk_label_new(_("URL:  "));
@@ -319,12 +308,11 @@ static void search_create_options(XfcePanelPlugin *plugin, t_search *search)
     /* url field */
     if(search->url!=NULL)
         gtk_entry_set_text(GTK_ENTRY(search->url_entry), search->url);
-    g_signal_connect (GTK_WIDGET(search->url_entry), "activate", G_CALLBACK (url_entry_activate_cb), search);
+    g_signal_connect (GTK_WIDGET(search->url_entry), "changed", G_CALLBACK (url_entry_changed_cb), search);
     gtk_grid_attach(GTK_GRID(grid), GTK_WIDGET(search->url_entry), 1, 2, 2, 1);
 
     gtk_widget_show_all(search->opt_dialog);
     gtk_dialog_run (GTK_DIALOG(search->opt_dialog));
-    search_apply_options_cb(search);
     gtk_widget_destroy(search->opt_dialog);
     xfce_panel_plugin_unblock_menu(plugin);
     search_write_config(plugin, search);
